# Bakery

The "Baker" configures the compute plane where the recipe is baked -
it wraps an [Apache Beam Runner](https://beam.apache.org/documentation/#runners)
in an opinionated fashion.

## DataflowBakery

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.bakery.dataflow.DataflowBakery
```

## LocalDirectBakery

```{eval-rst}
.. autoconfigurable::  pangeo_forge_runner.bakery.local.LocalDirectBakery
```
